@@ -1,6 +1,6 @@
 // { dg-require-namedlocale "en_US.UTF-8" }
 
-// Copyright (C) 2003, 2005, 2009, 2010 Free Software Foundation, Inc.
+// Copyright (C) 2003-2013 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -23,7 +23,7 @@
 #include <locale>
 #include <testsuite_hooks.h>
 
-void test04()
+void test03()
 {
   using namespace std;
   bool test __attribute__((unused)) = true;
@@ -31,18 +31,16 @@ void test04()
   wfilebuf fb;
   locale loc(locale("en_US.UTF-8"));
   fb.pubimbue(loc);
-  fb.open("tmp_11405-4", ios_base::out);
+  fb.open("tmp_11305-3", ios_base::out);
   wfilebuf::int_type n1 = fb.sputc(0x20000000);
-  wfilebuf::int_type n2 = fb.sputc(0x40000000);
   wfilebuf* f = fb.close();
-  
+	
   VERIFY( n1 != wfilebuf::traits_type::eof() );
-  VERIFY( n2 != wfilebuf::traits_type::eof() );
   VERIFY( f );
 }
 
 int main()
 {
-  test04();
+  test03();
   return 0;
 }
